/*
 * jQuery File Upload Plugin JS Example
 * https://github.com/blueimp/jQuery-File-Upload
 *
 * Copyright 2010, Sebastian Tschan
 * https://blueimp.net
 *
 * Licensed under the MIT license:
 * http://www.opensource.org/licenses/MIT
 */

/* global $, window */

$(function () {
    'use strict';

    // Initialize the jQuery File Upload widget:

	$('#fileupload').fileupload({
		acceptFileTypes: /(\.|\/)(gif|jpe?g|png)$/i,
		url: 'server/php/'
	}).on('fileuploadsubmit', function (e, data) {
		data.formData = data.context.find(':input').serializeArray();
	})
	.bind('fileuploaddestroy', function (e, data) {
		if (!window.confirm("Do you really want to delete?")) {
			return false;
		}
		else {
			var x = $("#nbrow").text();
			x--;
			$("#nbrow").text(x);
		}
	})
	.bind('fileuploadstop', function (e, data) {
		//fn_submit();
	});
	

    // Enable iframe cross-domain access via redirect option:
    $('#fileupload').fileupload(
        'option',
        'redirect',
        window.location.href.replace(
            /\/[^\/]*$/,
            '/cors/result.html?%s'
        )
    );

	//Default Date
	var period1 = 6;
	var period2 = 0;
	//////////////////
	
    if (window.location.hostname === 'blueimp.github.io') {
        // Demo settings:
        $('#fileupload').fileupload('option', {
            url: '//jquery-file-upload.appspot.com/',
            // Enable image resizing, except for Android and Opera,
            // which actually support image resizing, but fail to
            // send Blob objects via XHR requests:
            disableImageResize: /Android(?!.*Chrome)|Opera/
                .test(window.navigator.userAgent),
            maxFileSize: 999000,
            acceptFileTypes: /(\.|\/)(gif|jpe?g|png)$/i
        });
        // Upload server status check for browsers with CORS support:
        if ($.support.cors) {
            $.ajax({
                url: '//jquery-file-upload.appspot.com/',
                type: 'HEAD'
            }).fail(function () {
                $('<div class="alert alert-danger"/>')
                    .text('Upload server currently unavailable - ' +
                            new Date())
                    .appendTo('#fileupload');
            });
        }
    } else { // Keep Value Dropdownlist in session for Dropdownlist will not change when Reload Page
		$.post( "server/php/savefilter.php" ,  {cust_code: $('#custfilter').val(), tag_code: $('#tagfilter').val(), start_date: period1, end_date: period2}, function( data ) {
			$('#custfilter').val(data.cust_code);
			$('#tagfilter').val(data.tag_code);
			if(data.status){
				period1 = moment().diff(data.start_date, 'days');
				period2 = moment().diff(data.end_date, 'days');
			}
			else{
				period1 = data.start_date;
				period2 = data.end_date;
			}
			
			cb(moment().subtract(period1, 'days'), moment().subtract(period2, 'days'));
			
			$('#reportrange').daterangepicker({
				ranges: {
				   'Today': [moment(), moment()],
				   'Yesterday': [moment().subtract(1, 'days'), moment().subtract(1, 'days')],
				   'Last 7 Days': [moment().subtract(6, 'days'), moment()],
				   'Last 30 Days': [moment().subtract(29, 'days'), moment()],
				   'This Month': [moment().startOf('month'), moment().endOf('month')],
				   'Last Month': [moment().subtract(1, 'month').startOf('month'), moment().subtract(1, 'month').endOf('month')]
				},
				locale: {
				  format: 'YYYY-MM-DD'
				},
				"alwaysShowCalendars": true,
				"startDate": moment().subtract(period1, 'days'),
				"endDate": moment().subtract(period2, 'days'),
				"minDate": moment().subtract(3, 'months'),
				"maxDate": moment()
			}, cb);
			
		}, "json"); 
    }
	
	$('#custfilter').change(function() {
		fn_submit();
	});
	
	$('#tagfilter').change(function() {
		fn_submit();
	});
	
	var col_sort_default = $('#datatable').find('th').index($('.sort_default'));
	var taglist_html = $('#divtaglist').html();
	$('#divtaglist').remove();
	
	$('#datatable tbody').on( "click", ".tag_collapse", function(e) {
		var numcol = $('#datatable thead th').length;

		if($(this).parent().parent().next().attr('class') == "row_expand"){
			fn_clear_expand();
		}
		else{
			fn_clear_expand();
			$(this).parent().parent().after('<tr class="row_expand"><td colspan="'+numcol+'"></td></tr>');
			$('.row_expand').find('td').append('<div id="div_loading" class="row" align="center"></div>');
			$('.row_expand').find('td').append(taglist_html);
			$(this).removeClass('btn-success').addClass('btn-danger');
			$(this).find('i').removeClass('glyphicon-plus').addClass('glyphicon-minus');
			
			$('#div_loading').append('<img class="loading" src="img/loader.gif" />');
			$.post( "server/php/taglist.php" ,  {image_id : $(this).find(".id").text(), tag_id : 0}, function( data ) {
				$('#taglist tbody').html(data.lists);
			}, "json")
			.always(function() {
				$('.loading').remove();
			});
		}
		
	});
	
	$('#btndownload').on( "click", function(e) {
		var file_names = $("#datatable input:checkbox:checked").parent().parent().find('.name a').map(function(){
			return $(this).text();
		}).get();
		$('#fileupload').addClass('fileupload-processing');
		$.post( "server/php/downloadFile.php", {file_names: file_names, zip: true}, function(data) {

		})
		.done(function(data) {
			if(data){
				window.location.href = 'server/php/downloadFile.php';
			}
		})
		.always(function() {
			$('#fileupload').removeClass('fileupload-processing');
		});
	});
	
	function fn_clear_expand(){
		$('.row_expand').remove();
		$('.tag_collapse').removeClass('btn-danger').addClass('btn-success');
		$('.tag_collapse').find('i').removeClass('glyphicon-minus').addClass('glyphicon-plus');
	}
	
	function fn_submit(){
        // Load existing files:
		$( "input:checkbox" ).prop( "checked", false );
		$('#datatable tbody').empty();
		var period = $('#showperiod').text().split(" - ");
        $('#fileupload').addClass('fileupload-processing');
        $.ajax({
            // Uncomment the following to send cross-domain cookies:
            //xhrFields: {withCredentials: true},
            url: $('#fileupload').fileupload('option', 'url'),
			data: {cust_code: $('#custfilter').val(), tag_code: $('#tagfilter').val(), start_date: period[0], end_date: period[1]},
            dataType: 'json',
            context: $('#fileupload')[0]
        }).always(function () {
            $(this).removeClass('fileupload-processing');
        }).done(function (result) {
            $(this).fileupload('option', 'done')
                .call(this, $.Event('done'), {result: result});
			$("#nbrow").text(result['files'].length);
			highlightColumn($('#datatable'), col_sort_default, 'desc');
			$.post( "server/php/summary.php", {cust_code: $('#custfilter').val(), tag_code: $('#tagfilter').val(), start_date: period[0], end_date: period[1]}, function(data) {
				$('#tbsummary tbody').html(data);
			})
			.done(function(){
				$.post( "server/php/notification.php", { }, function(data) {
					if(data){

					}
					else{
						alert('unsuccessful');
					}
				});
			});
        });

	}
	
//Date Picker___________________________________________________________________________________
    function cb(start, end, label) {
        $('#reportrange span').html(start.format('YYYY-MM-DD') + ' - ' + end.format('YYYY-MM-DD'));
        var datediff = end.diff(start, 'days')+1;
		//$('#datelabel').text(label);
		$('#datediff').text(" (" + datediff + " Days)");
		var date1 = start.format('YYYY-MM-DD');
		var date2 = end.format('YYYY-MM-DD');
		fn_submit();
    }


/////////////////////////////////////////////////////////////////////////////////////////////////

//Sort Table___________________________________________________________________________________

 	$('#datatable th.sort_col').on( "click", function() {
		fn_clear_expand();
		highlightColumn($(this).parent().parent().parent(), $(this).index(), null);
	}); 
	
	var x = 0;
	var col_index = "";
	var col_label = $('#datatable').find('th').index($('.sort_label'));
	
	function highlightColumn(table, col, order){
		var sort = "";

		if(col_index == col){
			x++;
		}
		else{
			x = 1;
		}
		if(order == 'desc'){
			x = 0;
		}
		else if(order == 'asc'){
			x = 1;
		}
		if(x % 2 == 1){
			sort = 'asc';
			table.find('th i').removeClass().addClass("glyphicon glyphicon-sort pull-right");
			table.find('th:eq('+col+')').children().removeClass().addClass("glyphicon glyphicon-sort-by-attributes pull-right");
			table.find('th').removeClass();
			table.find('th:eq('+col+')').addClass("success");
		}
		else{
			sort = 'desc';
			table.find('th i').removeClass().addClass("glyphicon glyphicon-sort pull-right");
			table.find('th:eq('+col+')').children().removeClass().addClass("glyphicon glyphicon-sort-by-attributes-alt pull-right");
			table.find('th').removeClass();
			table.find('th:eq('+col+')').addClass("success");
		}
		col_index = col;
		sortTable(table, col, sort);
	}

	function sortTable(table, col, order) {
		var asc   = order === 'asc',
			tbody = table.find('tbody');

		tbody.find('tr.template-download').sort(function(a, b) {
			
			var data = 'td:eq('+col+') span';
			
			if(col == col_label){
				data = 'td:eq('+col+') label';
			}
			if (asc) {
				return $(data, a).text().localeCompare($(data, b).text());
			} else {
				return $(data, b).text().localeCompare($(data, a).text());
			}
		}).appendTo(tbody);
	}
/////////////////////////////////////////////////////////////////////////////////////////////////

});


